@@ -22,7 +22,11 @@ test_that("creation of polygons from raster works", {
 
 d <- raster::rasterize(lux, raster::raster(lux, res = 0.01))
 test_that("we can also qm_raster here", {
-  polygonize(d) %>% 
+  pd <- polygonize(d) 
+  pd %>% 
     expect_named(c("ID_1", "NAME_1", "ID_2", "NAME_2", "AREA", "geometry")) %>% 
     expect_s3_class("sf")
+  expect_equal(nrow(pd), 5694)
+  pnad <- polygonize(d, na.rm = TRUE)
+  expect_equal(nrow(pnad), 3195)
 })
